@@ -445,6 +445,7 @@ class Meshagent:
         user_id: str,
         is_admin: bool = False,
         is_developer: bool = False,
+        can_create_rooms: bool = False,
     ) -> Dict[str, Any]:
         """
         Corresponds to: POST /accounts/projects/:id/users
@@ -457,6 +458,7 @@ class Meshagent:
             "user_id": user_id,
             "is_admin": is_admin,
             "is_developer": is_developer,
+            "can_create_rooms": can_create_rooms,
         }
         async with self._session.post(
             url, headers=self._get_headers(), json=body
@@ -1126,7 +1128,7 @@ class Meshagent:
 
         url = f"{self.base_url}/accounts/projects/{project_id}/rooms/{room_name}/services/{service_id}"
         async with self._session.put(
-            url, headers=self._get_headers(), json=service.model_dump_json()
+            url, headers=self._get_headers(), json=service.model_dump(mode="json")
         ) as resp:
             resp.raise_for_status()
             await resp.json()
@@ -1285,13 +1287,24 @@ class Meshagent:
             except ValidationError as exc:
                 raise RoomException(f"Invalid room payload: {exc}") from exc
 
-    async def update_room(self, *, project_id: str, room_id: str, name: str) -> None:
+    async def update_room(
+        self,
+        *,
+        project_id: str,
+        room_id: str,
+        name: str,
+        metadata: Optional[dict[str, any]] = None,
+    ) -> None:
         """
         PUT /accounts/projects/{project_id}/rooms/{room_id}
         Body: { "name": str }
         """
         url = f"{self.base_url}/accounts/projects/{project_id}/rooms/{room_id}"
         payload = {"name": name}
+
+        if metadata is not None:
+            payload["metadata"] = metadata
+
         async with self._session.put(
             url, headers=self._get_headers(), json=payload
         ) as resp:
