@@ -95,13 +95,19 @@ class RoomAccessDeniedException(RoomException):
 
 
 class Requirement(ABC):
-    def __init__(self, *, name: str):
+    def __init__(self, *, name: str, callable: Optional[bool] = None):
         self.name = name
+        if callable is None:
+            callable = True
+
+        self.callable = callable
 
     @staticmethod
     def from_json(r: dict) -> "Requirement":
         if "toolkit" in r:
-            return RequiredToolkit(name=r["toolkit"], tools=r["tools"])
+            return RequiredToolkit(
+                name=r["toolkit"], tools=r["tools"], callable=r.get("callable", None)
+            )
 
         if "schema" in r:
             return RequiredSchema(name=r["schema"])
@@ -122,20 +128,26 @@ class _MakeCallRequest(BaseModel):
 
 class RequiredToolkit(Requirement):
     # Require a toolkit to be present for this tool to execute, optionally a list of specific tools in the toolkit
-    def __init__(self, *, name: str, tools: Optional[list["str"]] = None):
-        super().__init__(name=name)
+    def __init__(
+        self,
+        *,
+        name: str,
+        tools: Optional[list["str"]] = None,
+        callable: Optional[bool] = None,
+    ):
+        super().__init__(name=name, callable=callable)
         self.tools = tools
 
     def to_json(self):
-        return {"toolkit": self.name, "tools": self.tools}
+        return {"toolkit": self.name, "tools": self.tools, "callable": self.callable}
 
 
 class RequiredSchema(Requirement):
-    def __init__(self, *, name: str):
-        super().__init__(name=name)
+    def __init__(self, *, name: str, callable: Optional[bool] = None):
+        super().__init__(name=name, callable=callable)
 
     def to_json(self):
-        return {"schema": self.name}
+        return {"schema": self.name, "callable": self.callable}
 
 
 class _QueuedSync:
@@ -910,10 +922,10 @@ class StorageClient:
         """
 
         response = await self.room.send_request("storage.exists", {"path": path})
-        return response["exists"]
+        return response.json["exists"]
 
     async def stat(self, *, path: str) -> StorageEntry | None:
-        response = await self.room.send_request("storage.stat", {"path": path})
+        response = (await self.room.send_request("storage.stat", {"path": path})).json
         exists = response["exists"]
         if not exists:
             return None
@@ -921,8 +933,12 @@ class StorageClient:
             return StorageEntry(
                 name=response["name"],
                 is_folder=response["is_folder"],
-                created_at=datetime.fromisoformat(response["created_at"]),
-                updated_at=datetime.fromisoformat(response["updated_at"]),
+                created_at=datetime.fromisoformat(response["created_at"])
+                if response.get("created_at") is not None
+                else None,
+                updated_at=datetime.fromisoformat(response["updated_at"])
+                if response.get("updated_at") is not None
+                else None,
             )
 
     async def open(self, *, path: str, overwrite: bool = False):
@@ -1042,8 +1058,12 @@ class StorageClient:
                 lambda f: StorageEntry(
                     name=f["name"],
                     is_folder=f["is_folder"],
-                    created_at=datetime.fromisoformat(f["created_at"]),
-                    updated_at=datetime.fromisoformat(f["updated_at"]),
+                    created_at=datetime.fromisoformat(f["created_at"])
+                    if f.get("created_at") is not None
+                    else None,
+                    updated_at=datetime.fromisoformat(f["updated_at"])
+                    if f.get("updated_at") is not None
+                    else None,
                 ),
                 response["files"],
             )
